@@ -10,15 +10,15 @@
     SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef KSIEVE_IMPL_LEXER_H
-#define KSIEVE_IMPL_LEXER_H
+#pragma once
 
-#include <ksieve/lexer.h>
 #include <ksieve/error.h>
+#include <ksieve/lexer.h>
 
 #include <QStack>
 
-namespace KSieve {
+namespace KSieve
+{
 class Lexer::Impl
 {
 public:
@@ -105,14 +105,13 @@ private:
     struct State {
         State(const char *s = nullptr)
             : cursor(s)
-            , line(0)
             , beginOfLine(s)
             , error()
         {
         }
 
         const char *cursor;
-        int line;
+        int line = 0;
         const char *beginOfLine;
         Error error;
     } mState;
@@ -203,5 +202,3 @@ private:
     void skipToDelim();
 };
 }
-
-#endif
