@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ SelectMimeTypeComboBox::SelectMimeTypeComboBox(QWidget *parent)
     connect(this, &SelectMimeTypeComboBox::activated, this, &SelectMimeTypeComboBox::valueChanged);
 }
 
-SelectMimeTypeComboBox::~SelectMimeTypeComboBox()
-{
-}
+SelectMimeTypeComboBox::~SelectMimeTypeComboBox() = default;
 
 void SelectMimeTypeComboBox::initialize()
 {
