@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ SelectAddHeaderPositionCombobox::SelectAddHeaderPositionCombobox(QWidget *parent
     connect(this, &SelectAddHeaderPositionCombobox::activated, this, &SelectAddHeaderPositionCombobox::valueChanged);
 }
 
-SelectAddHeaderPositionCombobox::~SelectAddHeaderPositionCombobox()
-{
-}
+SelectAddHeaderPositionCombobox::~SelectAddHeaderPositionCombobox() = default;
 
 void SelectAddHeaderPositionCombobox::initialize()
 {
