@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ SelectImportanceCombobox::SelectImportanceCombobox(QWidget *parent)
     connect(this, &SelectImportanceCombobox::activated, this, &SelectImportanceCombobox::valueChanged);
 }
 
-SelectImportanceCombobox::~SelectImportanceCombobox()
-{
-}
+SelectImportanceCombobox::~SelectImportanceCombobox() = default;
 
 void SelectImportanceCombobox::initialize()
 {
