@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveactionwidgetlister.h"
-#include "autocreatescriptdialog.h"
 #include "autocreatescriptutil_p.h"
 #include "commonwidgets/sievehelpbutton.h"
 #include "sieveactions/sieveaction.h"
@@ -291,9 +290,7 @@ SieveActionWidgetLister::SieveActionWidgetLister(SieveEditorGraphicalModeWidget
     updateAddRemoveButton();
 }
 
-SieveActionWidgetLister::~SieveActionWidgetLister()
-{
-}
+SieveActionWidgetLister::~SieveActionWidgetLister() = default;
 
 void SieveActionWidgetLister::slotAddWidget(QWidget *w)
 {
@@ -384,7 +381,11 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
 {
     QString comment;
     if (onlyActions) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("action")) {
             if (element.attributes().hasAttribute(QLatin1String("name"))) {
                 const QString actionName = element.attributes().value(QLatin1String("name")).toString();
@@ -408,7 +409,11 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
         bool firstAction = true;
         bool previousActionWasAComment = false;
         while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const QStringRef tagName = element.name();
+#else
+            const QStringView tagName = element.name();
+#endif
             if (tagName == QLatin1String("action") || tagName == QLatin1String("control") /*for break action*/) {
                 if (element.attributes().hasAttribute(QLatin1String("name"))) {
                     const QString actionName = element.attributes().value(QLatin1String("name")).toString();
