@@ -1,17 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVECONDITION_H
-#define SIEVECONDITION_H
+#pragma once
 
-#include <QObject>
-#include <QUrl>
 #include "autocreatescripts/commonwidgets/sievecommonactioncondition.h"
 class QXmlStreamReader;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorGraphicalModeWidget;
 class SieveCondition : public SieveCommonActionCondition
 {
@@ -22,12 +20,15 @@ public:
 
     virtual void setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, bool notCondition, QString &error);
 
-    void unknownTag(const QStringRef &tag, QString &error) override;
     void unknownTagValue(const QString &tagValue, QString &error) override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    void unknownTag(const QStringRef &tag, QString &error) override;
     void tooManyArguments(const QStringRef &tagName, int index, int maxValue, QString &error) override;
+#else
+    void unknownTag(const QStringView &tag, QString &error) override;
+    void tooManyArguments(const QStringView &tagName, int index, int maxValue, QString &error) override;
+#endif
     void tooManyArguments(const QString &tagName, int index, int maxValue, QString &error);
     void serverDoesNotSupportFeatures(const QString &feature, QString &error) override;
 };
 }
-
-#endif // SIEVECONDITION_H
