@@ -1,70 +1,59 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionhasflag.h"
-#include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
+#include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include "editor/sieveeditorutil.h"
 
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
-#include <QWidget>
-#include <QHBoxLayout>
 #include "libksieve_debug.h"
-#include <QXmlStreamReader>
+#include <QHBoxLayout>
 #include <QLabel>
+#include <QWidget>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 SieveConditionHasFlag::SieveConditionHasFlag(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
     : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("hasflag"), i18n("Has Flag"), parent)
 {
-    hasVariableSupport = sieveCapabilities().contains(QStringLiteral("variables"));
+    hasVariableSupport = sieveCapabilities().contains(QLatin1String("variables"));
 }
 
 QWidget *SieveConditionHasFlag::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setMargin(0);
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
-    SelectMatchTypeComboBox *selecttype = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto selecttype = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     selecttype->setObjectName(QStringLiteral("matchtype"));
     connect(selecttype, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionHasFlag::valueChanged);
     lay->addWidget(selecttype);
 
-    QGridLayout *grid = new QGridLayout;
-    grid->setMargin(0);
+    auto grid = new QGridLayout;
+    grid->setContentsMargins({});
     lay->addLayout(grid);
 
     int row = 0;
     if (hasVariableSupport) {
-        QLabel *lab = new QLabel(i18n("Variable name\n (if empty it uses internal variable):"));
+        auto lab = new QLabel(i18n("Variable name\n (if empty it uses internal variable):"));
         grid->addWidget(lab, row, 0);
 
-        QLineEdit *variableName = new QLineEdit;
+        auto variableName = new QLineEdit;
+        new KPIM::LineEditCatchReturnKey(variableName, w);
         variableName->setObjectName(QStringLiteral("variablename"));
         connect(variableName, &QLineEdit::textChanged, this, &SieveConditionHasFlag::valueChanged);
         grid->addWidget(variableName, row, 1);
         ++row;
     }
-    QLabel *lab = new QLabel(i18n("Value:"));
+    auto lab = new QLabel(i18n("Value:"));
     grid->addWidget(lab, row, 0);
 
     AbstractRegexpEditorLineEdit *value = AutoCreateScriptUtil::createRegexpEditorLineEdit();
@@ -101,7 +90,7 @@ QString SieveConditionHasFlag::code(QWidget *w) const
 QStringList SieveConditionHasFlag::needRequires(QWidget *w) const
 {
     QStringList lst;
-    if (sieveCapabilities().contains(QStringLiteral("imap4flags"))) {
+    if (sieveCapabilities().contains(QLatin1String("imap4flags"))) {
         lst << QStringLiteral("imap4flags");
     } else {
         lst << QStringLiteral("imapflags");
@@ -123,9 +112,9 @@ QString SieveConditionHasFlag::serverNeedsCapability() const
 {
     return QStringLiteral("variables");
 #if 0
-    if (sieveCapabilities().contains(QStringLiteral("variables"))) {
+    if (sieveCapabilities().contains(QLatin1String("variables"))) {
     }
-    if (sieveCapabilities().contains(QStringLiteral("imap4flags"))) {
+    if (sieveCapabilities().contains(QLatin1String("imap4flags"))) {
         return QStringLiteral("imap4flags");
     } else {
         return QStringLiteral("imapflags");
@@ -138,20 +127,24 @@ QString SieveConditionHasFlag::help() const
     return i18n("The hasflag test evaluates to true if any of the variables matches any flag name.");
 }
 
-bool SieveConditionHasFlag::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
+void SieveConditionHasFlag::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
 {
     QStringList strList;
     QString commentStr;
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("tag")) {
-            SelectMatchTypeComboBox *matchTypeCombo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            auto matchTypeCombo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
             matchTypeCombo->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), notCondition), name(), error);
         } else if (tagName == QLatin1String("str")) {
             strList << element.readElementText();
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
@@ -164,17 +157,16 @@ bool SieveConditionHasFlag::setParamWidgetValue(QXmlStreamReader &element, QWidg
     }
 
     switch (strList.count()) {
-    case 1:
-    {
-        AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+    case 1: {
+        auto value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
         value->setCode(strList.at(0));
         break;
     }
     case 2:
         if (hasVariableSupport) {
-            QLineEdit *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
+            auto variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
             variableName->setText(strList.at(0));
-            AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+            auto value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
             value->setCode(strList.at(1));
         } else {
             qCDebug(LIBKSIEVE_LOG) << " SieveConditionHasFlag has not variable support";
@@ -184,8 +176,6 @@ bool SieveConditionHasFlag::setParamWidgetValue(QXmlStreamReader &element, QWidg
         qCDebug(LIBKSIEVE_LOG) << " SieveConditionHasFlag::setParamWidgetValue str list count not correct :" << strList.count();
         break;
     }
-
-    return true;
 }
 
 QUrl SieveConditionHasFlag::href() const
