@@ -1,29 +1,17 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionservermetadataexists.h"
-#include "editor/sieveeditorutil.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
+#include "editor/sieveeditorutil.h"
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
-#include <QHBoxLayout>
 #include "libksieve_debug.h"
+#include <QHBoxLayout>
 #include <QLabel>
 #include <QXmlStreamReader>
 
@@ -35,15 +23,16 @@ SieveConditionServerMetaDataExists::SieveConditionServerMetaDataExists(SieveEdit
 
 QWidget *SieveConditionServerMetaDataExists::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    QLabel *lab = new QLabel(i18n("Annotation:"));
+    auto lab = new QLabel(i18n("Annotation:"));
     lay->addWidget(lab);
 
-    QLineEdit *value = new QLineEdit;
+    auto value = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(value, w);
     value->setObjectName(QStringLiteral("value"));
     connect(value, &QLineEdit::textChanged, this, &SieveConditionServerMetaDataExists::valueChanged);
     lay->addWidget(value);
@@ -82,14 +71,18 @@ void SieveConditionServerMetaDataExists::setParamWidgetValue(QXmlStreamReader &e
 {
     QString commentStr;
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("str")) {
             const QString tagValue = element.readElementText();
-            QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("value"));
+            auto value = w->findChild<QLineEdit *>(QStringLiteral("value"));
             value->setText(tagValue);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
