@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVECONDITIONVIRUSTEST_H
-#define SIEVECONDITIONVIRUSTEST_H
+#pragma once
 
 #include "sievecondition.h"
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveConditionVirusTest : public SieveCondition
 {
     Q_OBJECT
@@ -31,4 +31,3 @@ public:
     Q_REQUIRED_RESULT QUrl href() const override;
 };
 }
-#endif // SIEVECONDITIONVIRUSTEST_H
