@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ SelectAddressPartComboBox::SelectAddressPartComboBox(SieveEditorGraphicalModeWid
     connect(this, &SelectAddressPartComboBox::activated, this, &SelectAddressPartComboBox::valueChanged);
 }
 
-SelectAddressPartComboBox::~SelectAddressPartComboBox()
-{
-}
+SelectAddressPartComboBox::~SelectAddressPartComboBox() = default;
 
 void SelectAddressPartComboBox::initialize()
 {
