@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ SelectComparatorComboBox::SelectComparatorComboBox(SieveEditorGraphicalModeWidge
     initialize(sieveGraphicalModeWidget->sieveCapabilities());
 }
 
-SelectComparatorComboBox::~SelectComparatorComboBox()
-{
-}
+SelectComparatorComboBox::~SelectComparatorComboBox() = default;
 
 void SelectComparatorComboBox::initialize(const QStringList &sieveCapabilities)
 {
@@ -37,7 +35,7 @@ void SelectComparatorComboBox::initialize(const QStringList &sieveCapabilities)
 QString SelectComparatorComboBox::require() const
 {
     if (currentIndex() < 2) {
-        return QString();
+        return {};
     }
     return itemData(currentIndex()).toString();
 }
