@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SELECTMIMECOMBOBOX_H
-#define SELECTMIMECOMBOBOX_H
+#pragma once
 #include <QComboBox>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SelectMimeComboBox : public QComboBox
 {
     Q_OBJECT
 public:
     explicit SelectMimeComboBox(QWidget *parent = nullptr);
-    ~SelectMimeComboBox();
+    ~SelectMimeComboBox() override;
 
     Q_REQUIRED_RESULT QString code() const;
     void setCode(const QString &code, const QString &name, QString &error);
@@ -27,5 +27,3 @@ private:
     void initialize();
 };
 }
-
-#endif // SELECTMIMECOMBOBOX_H
