@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveconditionwidgetlister.h"
-#include "autocreatescriptdialog.h"
 #include "autocreatescriptutil_p.h"
 #include "commonwidgets/sievehelpbutton.h"
 #include "libksieve_debug.h"
@@ -234,9 +233,7 @@ SieveConditionWidgetLister::SieveConditionWidgetLister(SieveEditorGraphicalModeW
     updateAddRemoveButton();
 }
 
-SieveConditionWidgetLister::~SieveConditionWidgetLister()
-{
-}
+SieveConditionWidgetLister::~SieveConditionWidgetLister() = default;
 
 void SieveConditionWidgetLister::slotAddWidget(QWidget *w)
 {
@@ -351,10 +348,18 @@ void SieveConditionWidgetLister::loadScript(QXmlStreamReader &element, bool uniq
             element.readNextStartElement();
         }
         while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const QStringRef tagName = element.name();
+#else
+            const QStringView tagName = element.name();
+#endif
             if (tagName == QLatin1String("testlist")) {
                 while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                     const QStringRef testTagName = element.name();
+#else
+                    const QStringView testTagName = element.name();
+#endif
                     if (testTagName == QLatin1String("test")) {
                         if (element.attributes().hasAttribute(QLatin1String("name"))) {
                             QString conditionName = element.attributes().value(QLatin1String("name")).toString();
