@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,6 +12,4 @@ SieveEditorGraphicalModeWidgetAbstract::SieveEditorGraphicalModeWidgetAbstract(Q
 {
 }
 
-SieveEditorGraphicalModeWidgetAbstract::~SieveEditorGraphicalModeWidgetAbstract()
-{
-}
+SieveEditorGraphicalModeWidgetAbstract::~SieveEditorGraphicalModeWidgetAbstract() = default;
