@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -54,9 +54,7 @@ SieveForEveryPartWidget::SieveForEveryPartWidget(QWidget *parent)
     setPageType(KSieveUi::SieveScriptBlockWidget::ForEveryPart);
 }
 
-SieveForEveryPartWidget::~SieveForEveryPartWidget()
-{
-}
+SieveForEveryPartWidget::~SieveForEveryPartWidget() = default;
 
 void SieveForEveryPartWidget::slotHelp()
 {
@@ -85,7 +83,11 @@ void SieveForEveryPartWidget::generatedScript(QString &script, QStringList &requ
 void SieveForEveryPartWidget::loadScript(QXmlStreamReader &element, QString &error)
 {
     if (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("tag")) {
             const QString tagValue = element.readElementText();
             if (tagValue == QLatin1String("name")) {
