@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,6 @@
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "autocreatescriptutil_p.h"
 #include "commonwidgets/sievehelpbutton.h"
-#include "editor/sieveeditorutil.h"
 #include "sievescriptblockwidget.h"
 #include "widgets/includefilelineedit.h"
 #include <Libkdepim/LineEditCatchReturnKey>
@@ -36,9 +35,7 @@ SieveIncludeLocation::SieveIncludeLocation(QWidget *parent)
     connect(this, &SieveIncludeLocation::activated, this, &SieveIncludeLocation::valueChanged);
 }
 
-SieveIncludeLocation::~SieveIncludeLocation()
-{
-}
+SieveIncludeLocation::~SieveIncludeLocation() = default;
 
 void SieveIncludeLocation::initialize()
 {
@@ -68,9 +65,7 @@ SieveIncludeActionWidget::SieveIncludeActionWidget(QWidget *parent)
     initWidget();
 }
 
-SieveIncludeActionWidget::~SieveIncludeActionWidget()
-{
-}
+SieveIncludeActionWidget::~SieveIncludeActionWidget() = default;
 
 void SieveIncludeActionWidget::clear()
 {
@@ -88,7 +83,11 @@ void SieveIncludeActionWidget::setListOfIncludeFile(const QStringList &listOfInc
 void SieveIncludeActionWidget::loadScript(QXmlStreamReader &element, QString &error)
 {
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("tag")) {
             const QString tagValue = element.readElementText();
             if (tagValue == QLatin1String("personal") || tagValue == QLatin1String("global")) {
@@ -110,8 +109,8 @@ void SieveIncludeActionWidget::loadScript(QXmlStreamReader &element, QString &er
 
 void SieveIncludeActionWidget::generatedScript(QString &script)
 {
-    const QString includeName = mIncludeFileName->text();
-    if (includeName.trimmed().isEmpty()) {
+    const QString includeName = mIncludeFileName->text().trimmed();
+    if (includeName.isEmpty()) {
         return;
     }
     script += QLatin1String("include ");
@@ -204,9 +203,7 @@ SieveIncludeWidget::SieveIncludeWidget(QWidget *parent)
     setPageType(KSieveUi::SieveScriptBlockWidget::Include);
 }
 
-SieveIncludeWidget::~SieveIncludeWidget()
-{
-}
+SieveIncludeWidget::~SieveIncludeWidget() = default;
 
 void SieveIncludeWidget::setListOfIncludeFile(const QStringList &lst)
 {
@@ -247,9 +244,7 @@ SieveIncludeWidgetLister::SieveIncludeWidgetLister(QWidget *parent)
     updateAddRemoveButton();
 }
 
-SieveIncludeWidgetLister::~SieveIncludeWidgetLister()
-{
-}
+SieveIncludeWidgetLister::~SieveIncludeWidgetLister() = default;
 
 void SieveIncludeWidgetLister::slotAddWidget(QWidget *w)
 {
