@@ -1,44 +1,33 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievescriptlistbox.h"
-#include "sievescriptdescriptiondialog.h"
-#include "sieveglobalvariablewidget.h"
-#include "sieveforeverypartwidget.h"
-#include "sievescriptpage.h"
-#include "sieveincludewidget.h"
 #include "sieveeditorgraphicalmodewidget.h"
-#include <QXmlStreamReader>
-#include <QHBoxLayout>
-#include <KMessageBox>
+#include "sieveforeverypartwidget.h"
+#include "sieveglobalvariablewidget.h"
+#include "sieveincludewidget.h"
+#include "sievescriptdescriptiondialog.h"
+#include "sievescriptpage.h"
 #include <KLocalizedString>
+#include <KMessageBox>
+#include <QHBoxLayout>
+#include <QIcon>
 #include <QInputDialog>
 #include <QPushButton>
-#include <QIcon>
+#include <QXmlStreamReader>
 
-#include <QVBoxLayout>
-#include <QListWidget>
-#include <QPointer>
-#include <QMenu>
 #include "libksieve_debug.h"
+#include <QListWidget>
+#include <QMenu>
+#include <QPointer>
+#include <QVBoxLayout>
+#include <kwidgetsaddons_version.h>
 
-namespace {
+namespace
+{
 inline const QString defaultScriptName()
 {
     return QStringLiteral("SCRIPTNAME: ");
@@ -52,9 +41,7 @@ SieveScriptListItem::SieveScriptListItem(const QString &text, QListWidget *paren
 {
 }
 
-SieveScriptListItem::~SieveScriptListItem()
-{
-}
+SieveScriptListItem::~SieveScriptListItem() = default;
 
 void SieveScriptListItem::setDescription(const QString &desc)
 {
@@ -80,8 +67,13 @@ QString SieveScriptListItem::generatedScript(QStringList &required) const
 {
     QString script;
     if (!mDescription.trimmed().isEmpty()) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        const QVector<QStringView> commentList = QStringView(mDescription).split(QLatin1Char('\n'));
+        for (const QStringView str : commentList) {
+#else
         const QVector<QStringRef> commentList = mDescription.splitRef(QLatin1Char('\n'));
         for (const QStringRef &str : commentList) {
+#endif
             if (str.isEmpty()) {
                 script += QLatin1Char('\n');
             } else {
@@ -97,10 +89,10 @@ QString SieveScriptListItem::generatedScript(QStringList &required) const
 
 SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     : QGroupBox(title, parent)
+    , mSieveListScript(new QListWidget(this))
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setObjectName(QStringLiteral("layout"));
-    mSieveListScript = new QListWidget(this);
     mSieveListScript->setObjectName(QStringLiteral("mSieveListScript"));
     mSieveListScript->setDragDropMode(QAbstractItemView::InternalMove);
     mSieveListScript->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -108,9 +100,9 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     layout->addWidget(mSieveListScript);
 
     //----------- the first row of buttons
-    QWidget *hb = new QWidget(this);
-    QHBoxLayout *hbHBoxLayout = new QHBoxLayout(hb);
-    hbHBoxLayout->setContentsMargins(0, 0, 0, 0);
+    auto hb = new QWidget(this);
+    auto hbHBoxLayout = new QHBoxLayout(hb);
+    hbHBoxLayout->setContentsMargins({});
     hbHBoxLayout->setSpacing(4);
 
     mBtnTop = new QPushButton(hb);
@@ -143,7 +135,7 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
 
     hb = new QWidget(this);
     hbHBoxLayout = new QHBoxLayout(hb);
-    hbHBoxLayout->setContentsMargins(0, 0, 0, 0);
+    hbHBoxLayout->setContentsMargins({});
     hbHBoxLayout->setSpacing(4);
 
     mBtnNew = new QPushButton(hb);
@@ -189,9 +181,7 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     updateButtons();
 }
 
-SieveScriptListBox::~SieveScriptListBox()
-{
-}
+SieveScriptListBox::~SieveScriptListBox() = default;
 
 void SieveScriptListBox::slotCustomMenuRequested(const QPoint &pos)
 {
@@ -210,7 +200,7 @@ void SieveScriptListBox::slotCustomMenuRequested(const QPoint &pos)
         deleteScriptAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
         connect(deleteScriptAction, &QAction::triggered, this, &SieveScriptListBox::slotDelete);
     }
-    menu.exec(mapToGlobal(pos));
+    menu.exec(QCursor::pos());
 }
 
 void SieveScriptListBox::setSieveEditorGraphicalModeWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget)
@@ -221,7 +211,7 @@ void SieveScriptListBox::setSieveEditorGraphicalModeWidget(SieveEditorGraphicalM
 void SieveScriptListBox::slotItemActived(QListWidgetItem *item)
 {
     if (item) {
-        SieveScriptListItem *itemScript = static_cast<SieveScriptListItem *>(item);
+        auto itemScript = static_cast<SieveScriptListItem *>(item);
         Q_EMIT activatePage(itemScript->scriptPage());
     }
 }
@@ -245,9 +235,9 @@ void SieveScriptListBox::updateButtons()
 
 SieveScriptPage *SieveScriptListBox::createNewScript(const QString &newName, const QString &description)
 {
-    SieveScriptListItem *item = new SieveScriptListItem(newName, mSieveListScript);
+    auto item = new SieveScriptListItem(newName, mSieveListScript);
     item->setDescription(description);
-    SieveScriptPage *page = new SieveScriptPage(mSieveGraphicalModeWidget);
+    auto page = new SieveScriptPage(mSieveGraphicalModeWidget);
     page->setListOfIncludeFile(mSieveGraphicalModeWidget->listOfIncludeFile());
     item->setScriptPage(page);
     Q_EMIT addNewPage(page);
@@ -259,8 +249,9 @@ SieveScriptPage *SieveScriptListBox::createNewScript(const QString &newName, con
 
 void SieveScriptListBox::slotNew()
 {
-    const QString newName = QInputDialog::getText(this, i18nc("@title:window", "New Script"), i18n("New script name:"));
-    if (!newName.trimmed().isEmpty()) {
+    bool ok;
+    const QString newName = QInputDialog::getText(this, i18nc("@title:window", "New Script"), i18n("New script name:"), {}, {}, &ok);
+    if (!newName.trimmed().isEmpty() && ok) {
         createNewScript(newName);
         Q_EMIT valueChanged();
     }
@@ -270,9 +261,21 @@ void SieveScriptListBox::slotDelete()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        if (KMessageBox::warningYesNo(this, i18n("Do you want to delete \"%1\" script?", item->text()),
-                                      i18nc("@title:window", "Delete Script")) == KMessageBox::Yes) {
-            SieveScriptListItem *itemScript = static_cast<SieveScriptListItem *>(item);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const int answer = KMessageBox::warningTwoActions(this,
+#else
+        const int answer = KMessageBox::warningYesNo(this,
+#endif
+                                                          i18n("Do you want to delete \"%1\" script?", item->text()),
+                                                          i18nc("@title:window", "Delete Script"),
+                                                          KStandardGuiItem::del(),
+                                                          KStandardGuiItem::cancel());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+#else
+        if (answer == KMessageBox::Yes) {
+#endif
+            auto itemScript = static_cast<SieveScriptListItem *>(item);
             Q_EMIT removePage(itemScript->scriptPage());
             delete item;
             Q_EMIT enableButtonOk(mSieveListScript->count() > 0);
@@ -286,11 +289,15 @@ void SieveScriptListBox::slotRename()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        QString newName = QInputDialog::getText(this, i18nc("@title:window", "Rename Script"), i18n("New name for the script:"), QLineEdit::Normal, item->text());
-        newName = newName.trimmed();
-        if (!newName.isEmpty()) {
-            item->setText(newName);
-            Q_EMIT valueChanged();
+        bool ok = false;
+        QString newName =
+            QInputDialog::getText(this, i18nc("@title:window", "Rename Script"), i18n("New name for the script:"), QLineEdit::Normal, item->text(), &ok);
+        if (ok) {
+            newName = newName.trimmed();
+            if (!newName.isEmpty()) {
+                item->setText(newName);
+                Q_EMIT valueChanged();
+            }
         }
     }
 }
@@ -299,7 +306,7 @@ void SieveScriptListBox::slotEditDescription()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        SieveScriptListItem *sieveItem = static_cast<SieveScriptListItem *>(item);
+        auto sieveItem = static_cast<SieveScriptListItem *>(item);
         QPointer<SieveScriptDescriptionDialog> dlg = new SieveScriptDescriptionDialog(this);
         dlg->setDescription(sieveItem->description());
         if (dlg->exec()) {
@@ -372,7 +379,7 @@ QString SieveScriptListBox::generatedScript(QStringList &requireModules) const
     QStringList lstRequires;
     const int numberOfScripts(mSieveListScript->count());
     for (int i = 0; i < numberOfScripts; ++i) {
-        SieveScriptListItem *item = static_cast<SieveScriptListItem *>(mSieveListScript->item(i));
+        auto item = static_cast<SieveScriptListItem *>(mSieveListScript->item(i));
         if (i != 0) {
             resultScript += QLatin1String("\n\n");
         }
@@ -384,7 +391,7 @@ QString SieveScriptListBox::generatedScript(QStringList &requireModules) const
     }
 
     QStringList endRequires;
-    for (const QString &r : qAsConst(lstRequires)) {
+    for (const QString &r : std::as_const(lstRequires)) {
         if (!endRequires.contains(r)) {
             endRequires.append(r);
             requireModules += QStringLiteral("require \"%1\";").arg(r);
@@ -398,7 +405,7 @@ void SieveScriptListBox::clear()
 {
     mScriptNumber = 0;
     Q_EMIT enableButtonOk(false);
-    //Clear tabpage
+    // Clear tabpage
     mSieveListScript->clear();
     updateButtons();
 }
@@ -423,17 +430,21 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
     bool hasCreatedAIfBlock = false;
     bool previousElementWasAComment = false;
     while (n.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = n.name();
-        //qDebug() <<"SieveScriptListBox::loadBlock tagName " << tagName;
+#else
+        const QStringView tagName = n.name();
+#endif
+        // qDebug() <<"SieveScriptListBox::loadBlock tagName " << tagName;
         if (tagName == QLatin1String("control")) {
             previousElementWasAComment = false;
-            //Create a new page when before it was "onlyactions"
+            // Create a new page when before it was "onlyactions"
             if (typeBlock == TypeBlockAction) {
                 currentPage = nullptr;
             }
             if (n.attributes().hasAttribute(QLatin1String("name"))) {
                 const QString controlType = n.attributes().value(QLatin1String("name")).toString();
-                //qCDebug(LIBKSIEVE_LOG)<<" controlType"<<controlType;
+                // qCDebug(LIBKSIEVE_LOG)<<" controlType"<<controlType;
                 if (controlType == QLatin1String("if")) {
                     typeBlock = TypeBlockIf;
                     if (!currentPage || hasCreatedAIfBlock) {
@@ -462,7 +473,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                     if (blockWidget) {
                         blockWidget->loadScript(n, false, error);
                     }
-                    //We are sure that we can't have another elsif
+                    // We are sure that we can't have another elsif
                     currentPage = nullptr;
                 } else if (controlType == QLatin1String("foreverypart")) {
                     typeBlock = TypeBlockForeachBlock;
@@ -475,14 +486,14 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                     } else {
                         error += i18n("forEveryPart is not supported by your server") + QLatin1Char('\n');
                     }
-                    //TODO verify it.
+                    // TODO verify it.
 #ifdef QDOMELEMENT_FIXME
                     QDomNode block = e.firstChildElement(QStringLiteral("block")).firstChild();
                     loadBlock(block, currentPage, typeBlock, error);
 #endif
                 } else if (controlType == QLatin1String("require")) {
                     n.skipCurrentElement();
-                    //Nothing. autogenerated
+                    // Nothing. autogenerated
                 } else {
                     qCDebug(LIBKSIEVE_LOG) << " unknown controlType :" << controlType;
                 }
@@ -491,9 +502,9 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
             previousElementWasAComment = true;
 #ifdef FIXME_COMMENT
             if (e.hasAttribute(QStringLiteral("hash"))) {
-                //TODO
+                // TODO
             } else if (e.hasAttribute(QStringLiteral("bracket"))) {
-                //TODO
+                // TODO
             }
 #endif
             QString str(n.readElementText());
@@ -505,7 +516,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                 }
                 comment += str;
             }
-            //qDebug() << " COMMENT " << comment;
+            // qDebug() << " COMMENT " << comment;
         } else if (tagName == QLatin1String("action")) {
             previousElementWasAComment = false;
             if (n.attributes().hasAttribute(QLatin1String("name"))) {
@@ -533,7 +544,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                         qCDebug(LIBKSIEVE_LOG) << " globalVariable not supported";
                     }
                 } else if (actionName == QLatin1String("set") && (typeBlock == TypeBlockGlobal)) {
-                    //FIXME global not global variable.
+                    // FIXME global not global variable.
                     if (currentPage->globalVariableWidget()) {
                         const SieveGlobalVariableActionWidget::VariableElement var = currentPage->globalVariableWidget()->loadSetVariable(n, error);
                         if (var.isValid()) {
@@ -558,7 +569,7 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
                 }
             }
         } else if (tagName == QLatin1String("crlf")) {
-            //If it was a comment previously you will create a \n
+            // If it was a comment previously you will create a \n
             if (previousElementWasAComment) {
                 comment += QLatin1Char('\n');
             }
