@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,9 +25,7 @@ SieveScriptTabWidget::SieveScriptTabWidget(QWidget *parent)
     connect(this, &SieveScriptTabWidget::customContextMenuRequested, this, &SieveScriptTabWidget::slotTabContextMenuRequest);
 }
 
-SieveScriptTabWidget::~SieveScriptTabWidget()
-{
-}
+SieveScriptTabWidget::~SieveScriptTabWidget() = default;
 
 void SieveScriptTabWidget::slotTabContextMenuRequest(const QPoint &pos)
 {
