@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,6 @@
 
 #include "../src/ksieveui/scriptsparsing/parsingresultdialog.h"
 #include "../src/ksieveui/scriptsparsing/xmlprintingscriptbuilder.h"
-#include <QPointer>
 
 #include <ksieve/parser.h>
 using KSieve::Parser;
@@ -70,10 +69,9 @@ int main(int argc, char **argv)
     QString error;
     dialog->loadScript(psb.result(), error);
     if (!error.isEmpty()) {
-        QPointer<KSieveUi::SieveScriptParsingErrorDialog> dlg = new KSieveUi::SieveScriptParsingErrorDialog;
-        dlg->setError(QString::fromLatin1(script), error);
-        dlg->exec();
-        delete dlg;
+        KSieveUi::SieveScriptParsingErrorDialog dlgError;
+        dlgError.setError(QString::fromLatin1(script), error);
+        dlgError.exec();
     }
 
     dialog->show();
