@@ -1,19 +1,6 @@
-/* Copyright (C) 2011-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "sieveeditor.h"
@@ -23,33 +10,35 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include <QPushButton>
-#include <QKeyEvent>
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KSharedConfig>
 #include <QDialogButtonBox>
+#include <QKeyEvent>
+#include <QPushButton>
 #include <QVBoxLayout>
+#include <kwidgetsaddons_version.h>
 
 using namespace KSieveUi;
 class KSieveUi::SieveEditorPrivate
 {
 public:
-    SieveEditorPrivate()
-    {
-    }
+    SieveEditorPrivate() = default;
 
     SieveEditorWidget *mSieveEditorWidget = nullptr;
     QPushButton *mOkButton = nullptr;
 };
-
+namespace
+{
+static const char mySieveEditorGroupName[] = "SieveEditor";
+}
 SieveEditor::SieveEditor(QWidget *parent)
     : QDialog(parent)
     , d(new KSieveUi::SieveEditorPrivate)
 {
     setWindowTitle(i18nc("@title:window", "Edit Sieve Script"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     d->mOkButton->setDefault(true);
     d->mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -68,13 +57,12 @@ SieveEditor::SieveEditor(QWidget *parent)
 SieveEditor::~SieveEditor()
 {
     writeConfig();
-    delete d;
 }
 
 void SieveEditor::slotAccepted()
 {
     Q_EMIT okClicked();
-    //Don't accept here we need to check script. If it's failed we don't close this editor otherwise we will lose data
+    // Don't accept here we need to check script. If it's failed we don't close this editor otherwise we will lose data
 }
 
 void SieveEditor::slotCanceled()
@@ -91,7 +79,7 @@ bool SieveEditor::event(QEvent *e)
     // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
-        QKeyEvent *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             e->ignore();
             return true;
@@ -112,13 +100,13 @@ void SieveEditor::slotEnableButtonOk(bool b)
 
 void SieveEditor::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditor");
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorGroupName);
     group.writeEntry("Size", size());
 }
 
 void SieveEditor::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditor");
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorGroupName);
     const QSize sizeDialog = group.readEntry("Size", QSize(800, 600));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -188,7 +176,20 @@ void SieveEditor::addNormalMessage(const QString &msg)
 void SieveEditor::closeEvent(QCloseEvent *e)
 {
     if (d->mSieveEditorWidget->originalScript() != d->mSieveEditorWidget->script()) {
-        if (KMessageBox::No == KMessageBox::warningYesNo(this, i18n("Script is modified. Do you want to close editor ?"))) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const int answer = KMessageBox::warningTwoActions(this,
+#else
+        const int answer = KMessageBox::warningYesNo(this,
+#endif
+                                                          i18n("Script is modified. Do you want to close editor?"),
+                                                          QString(),
+                                                          KGuiItem(i18nc("@action:button", "Close Editor"), QStringLiteral("dialog-close")),
+                                                          KGuiItem(i18nc("@action:button", "Do Not Close"), QStringLiteral("dialog-cancel")));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (answer == KMessageBox::ButtonCode::SecondaryAction) {
+#else
+        if (answer == KMessageBox::No) {
+#endif
             e->ignore();
             return;
         }
