@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -9,21 +9,17 @@
 #include "sievepurposemenuwidget.h"
 
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
-#include "autocreatescripts/sievescriptparsingerrordialog.h"
 #include "editor/sieveinfodialog.h"
 #include "scriptsparsing/parsingutil.h"
 #include "sieve-editor.h"
 #include "sieveeditormenubar.h"
 #include "sieveeditortextmodewidget.h"
 
+#include "libksieve_debug.h"
 #include <KActionMenu>
 #include <KLocalizedString>
 #include <KStandardAction>
-#include <kzip.h>
-
 #include <PimCommon/PurposeMenuWidget>
-
-#include "libksieve_debug.h"
 #include <QAction>
 #include <QLabel>
 #include <QLineEdit>
@@ -32,6 +28,7 @@
 #include <QStandardPaths>
 #include <QToolBar>
 #include <QVBoxLayout>
+#include <kzip.h>
 
 using namespace KSieveUi;
 
@@ -41,7 +38,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     auto lay = new QVBoxLayout(this);
     mDebug = !qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING");
 
-    auto toolbar = new QToolBar;
+    auto toolbar = new QToolBar(this);
     toolbar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
 
     mCheckSyntax = new QAction(i18n("Check Syntax"), this);
@@ -64,7 +61,6 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
         connect(mGenerateXml, &QAction::triggered, this, &SieveEditorWidget::slotGenerateXml);
         toolbar->addAction(mGenerateXml);
     }
-
     auto purposeMenu = new SievePurposeMenuWidget(this, this);
     auto shareAction = new KActionMenu(i18n("Share..."), this);
     shareAction->setPopupMode(QToolButton::InstantPopup);
@@ -72,7 +68,6 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     shareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
     purposeMenu->setEditorWidget(this);
     toolbar->addAction(shareAction);
-
     mServerInfo = new QAction(i18n("Server Info"), this);
     connect(mServerInfo, &QAction::triggered, this, &SieveEditorWidget::slotServerInfo);
     toolbar->addAction(mServerInfo);
@@ -96,7 +91,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
         connect(menuBar, &SieveEditorMenuBar::zoomOut, this, &SieveEditorWidget::zoomOut);
         connect(menuBar, &SieveEditorMenuBar::zoomReset, this, &SieveEditorWidget::zoomReset);
         connect(menuBar, &SieveEditorMenuBar::debugSieveScript, this, &SieveEditorWidget::debugSieveScript);
-        connect(menuBar, &SieveEditorMenuBar::wordWrap, this, &SieveEditorWidget::wordWrap);
+        connect(menuBar, &SieveEditorMenuBar::wordWrap, this, &SieveEditorWidget::setWordWrap);
         connect(menuBar, &SieveEditorMenuBar::print, this, &SieveEditorWidget::print);
         connect(menuBar, &SieveEditorMenuBar::printPreview, this, &SieveEditorWidget::printPreview);
 
@@ -153,9 +148,7 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     }
 }
 
-SieveEditorWidget::~SieveEditorWidget()
-{
-}
+SieveEditorWidget::~SieveEditorWidget() = default;
 
 void SieveEditorWidget::setReadOnly(bool b)
 {
@@ -270,10 +263,10 @@ void SieveEditorWidget::printPreview()
     }
 }
 
-void SieveEditorWidget::wordWrap(bool state)
+void SieveEditorWidget::setWordWrap(bool state)
 {
     if (mMode == TextMode) {
-        mTextModeWidget->wordWrap(state);
+        mTextModeWidget->setWordWrap(state);
     }
 }
 
@@ -658,7 +651,7 @@ QString SieveEditorWidget::currentHelpTitle() const
     if (mMode == TextMode) {
         return mTextModeWidget->currentHelpTitle();
     }
-    return QString();
+    return {};
 }
 
 QUrl SieveEditorWidget::currentHelpUrl() const
@@ -666,7 +659,7 @@ QUrl SieveEditorWidget::currentHelpUrl() const
     if (mMode == TextMode) {
         return mTextModeWidget->currentHelpUrl();
     }
-    return QUrl();
+    return {};
 }
 
 bool SieveEditorWidget::isTextEditor() const
