@@ -1,32 +1,19 @@
 /*
-  Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef SIEVEEDITORWIDGET_H
-#define SIEVEEDITORWIDGET_H
+#pragma once
 #include "ksieveui_export.h"
 
 #include <QWidget>
 class QStackedWidget;
 class QLineEdit;
 class QAction;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveImapAccountSettings;
 class SieveEditorTextModeWidget;
 class SieveEditorGraphicalModeWidget;
@@ -39,12 +26,8 @@ class KSIEVEUI_EXPORT SieveEditorWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveEditorWidget(bool useMenuBar, QWidget *parent = nullptr);
-    ~SieveEditorWidget();
-    enum EditorMode {
-        Unknown = -1,
-        TextMode = 0,
-        GraphicMode = 1
-    };
+    ~SieveEditorWidget() override;
+    enum EditorMode { Unknown = -1, TextMode = 0, GraphicMode = 1 };
 
     void setReadOnly(bool b);
     Q_REQUIRED_RESULT QString script() const;
@@ -105,12 +88,11 @@ public Q_SLOTS:
     void goToLine();
     void slotSaveAs();
     void slotImport();
-    void slotShareScript();
     void slotCreateRulesGraphically();
     void slotCheckSyntax();
     void comment();
     void uncomment();
-    void wordWrap(bool state);
+    void setWordWrap(bool state);
 
 Q_SIGNALS:
     void checkSyntax();
@@ -122,6 +104,7 @@ Q_SIGNALS:
     void copyAvailable(bool);
     void changeModeEditor(bool);
     void sieveEditorTabCurrentChanged();
+
 private:
     void slotEnableButtonOk(bool b);
     void slotGenerateXml();
@@ -142,7 +125,6 @@ private:
     QAction *mSwitchMode = nullptr;
     QAction *mCreateRulesGraphically = nullptr;
     QAction *mSaveAs = nullptr;
-    QAction *mShareScript = nullptr;
     QAction *mGenerateXml = nullptr;
     QAction *mServerInfo = nullptr;
     EditorMode mMode = EditorMode::TextMode;
@@ -150,5 +132,3 @@ private:
     bool mDebug = false;
 };
 }
-
-#endif // SIEVEEDITORWIDGET_H
