@@ -1,21 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEEDITORLOADPROGRESSINDICATOR_H
-#define SIEVEEDITORLOADPROGRESSINDICATOR_H
+#pragma once
 
-#include <QObject>
 #include <KPixmapSequence>
+#include <QObject>
 class QTimer;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorLoadProgressIndicator : public QObject
 {
     Q_OBJECT
 public:
     explicit SieveEditorLoadProgressIndicator(QObject *parent = nullptr);
-    ~SieveEditorLoadProgressIndicator();
+    ~SieveEditorLoadProgressIndicator() override;
 
     void startAnimation();
     void stopAnimation(bool success);
@@ -29,8 +29,6 @@ private:
     void slotTimerDone();
     int mProgressCount = 0;
     KPixmapSequence mProgressPix;
-    QTimer *mProgressTimer = nullptr;
+    QTimer *const mProgressTimer;
 };
 }
-
-#endif // SIEVEEDITORLOADPROGRESSINDICATOR_H
