@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -25,9 +25,7 @@ RenameScriptJob::RenameScriptJob(QObject *parent)
 {
 }
 
-RenameScriptJob::~RenameScriptJob()
-{
-}
+RenameScriptJob::~RenameScriptJob() = default;
 
 void RenameScriptJob::setOldUrl(const QUrl &url)
 {
