@@ -1,25 +1,22 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "managesievescriptsdialog.h"
 #include "editor/sieveeditor.h"
-#include "editor/sievetextedit.h"
 #include "managescriptsjob/checkscriptjob.h"
 #include "widgets/custommanagesievewidget.h"
-#include "widgets/managesievetreeview.h"
-#include "widgets/sievetreewidgetitem.h"
 
 #include "util/sieveimapaccountsettings.h"
 
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QHideEvent>
 #include <QPushButton>
 
-#include "libksieve_debug.h"
 #include <kmanagesieve/sievejob.h>
 
 #include <QTreeWidget>
@@ -35,9 +32,7 @@ using namespace KSieveUi;
 class KSieveUi::ManageSieveScriptsDialogPrivate
 {
 public:
-    ManageSieveScriptsDialogPrivate()
-    {
-    }
+    ManageSieveScriptsDialogPrivate() = default;
 
     CustomManageSieveWidget *mTreeView = nullptr;
     SieveEditor *mSieveEditor = nullptr;
@@ -62,7 +57,7 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
 {
     setWindowTitle(i18nc("@title:window", "Manage Sieve Scripts"));
     setModal(false);
-    setAttribute(Qt::WA_GroupLeader);
+    setWindowModality(Qt::WindowModal);
     setAttribute(Qt::WA_DeleteOnClose);
     auto mainLayout = new QVBoxLayout(this);
     auto frame = new QFrame;
