@@ -6,9 +6,7 @@
 
 #include "xmlprintingscriptbuilder.h"
 #include <ksieve/parser.h>
-using KSieve::Parser;
 
-#include "libksieve_debug.h"
 #include <QXmlStreamWriter>
 #include <ksieve/error.h>
 
