@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SIEVESCRIPTDEBUGGERFRONTENDWIDGETTEST_H
-#define SIEVESCRIPTDEBUGGERFRONTENDWIDGETTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,12 +13,10 @@ class SieveScriptDebuggerFrontEndWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit SieveScriptDebuggerFrontEndWidgetTest(QObject *parent = nullptr);
-    ~SieveScriptDebuggerFrontEndWidgetTest();
+    ~SieveScriptDebuggerFrontEndWidgetTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldChangeButtonEnabledState();
     void shouldAddScript();
     void shouldNotAccept();
 };
-
-#endif // SIEVESCRIPTDEBUGGERFRONTENDWIDGETTEST_H
