@@ -1,44 +1,47 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievescriptdebuggerfrontendwidget.h"
+#include "sievescriptdebuggerresulteditor.h"
 #include "sievescriptdebuggertextedit.h"
 #include "sievescriptdebuggerwarning.h"
-#include "sievescriptdebuggerresulteditor.h"
 
-#include <QScrollBar>
-#include <QVBoxLayout>
-#include <QSplitter>
-#include <QTemporaryFile>
-#include <QProcess>
-#include <QTextStream>
-#include <QFormLayout>
-#include "editor/sievetexteditwidget.h"
 #include "editor/sievetextedit.h"
-#include <KPIMTextEdit/PlainTextEditorWidget>
-#include <KPIMTextEdit/TextToSpeechWidget>
-#include <Libkdepim/LineEditCatchReturnKey>
-#include <QLabel>
-#include <KUrlRequester>
+#include "editor/sievetexteditwidget.h"
 #include <KLineEdit>
 #include <KLocalizedString>
+#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+#include <KPIMTextEdit/TextToSpeechWidget>
+#endif
+#include <KUrlRequester>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QDate>
+#include <QFormLayout>
+#include <QLabel>
+#include <QProcess>
+#include <QScrollBar>
+#include <QSplitter>
+#include <QTemporaryFile>
+#include <QTextStream>
+#include <QVBoxLayout>
 
 using namespace KSieveUi;
 
 SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setContentsMargins({});
 
-    auto *formLayout = new QFormLayout;
+    auto formLayout = new QFormLayout;
     mainLayout->addLayout(formLayout);
 
-    QLabel *emailLab = new QLabel(i18n("Email path:"), this);
+    auto emailLab = new QLabel(i18n("Email path:"), this);
     emailLab->setObjectName(QStringLiteral("emaillab"));
 
     mEmailPath = new KUrlRequester(this);
@@ -49,10 +52,10 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
 
     formLayout->addRow(emailLab, mEmailPath);
 
-    auto *extensionLayout = new QHBoxLayout;
+    auto extensionLayout = new QHBoxLayout;
     mainLayout->addLayout(extensionLayout);
 
-    QLabel *extensionLab = new QLabel(i18n("Extension:"));
+    auto extensionLab = new QLabel(i18n("Extension:"));
     extensionLab->setObjectName(QStringLiteral("extensionlab"));
 
     mExtension = new QLineEdit(this);
@@ -67,22 +70,23 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
     mSplitter->setObjectName(QStringLiteral("splitter"));
     mainLayout->addWidget(mSplitter);
 
-    QWidget *sieveEditorWidget = new QWidget(this);
-    auto *vboxSieveEditorLayout = new QVBoxLayout;
+    auto sieveEditorWidget = new QWidget(this);
+    auto vboxSieveEditorLayout = new QVBoxLayout;
     sieveEditorWidget->setLayout(vboxSieveEditorLayout);
     vboxSieveEditorLayout->setContentsMargins({});
-
-    auto *textToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+    auto textToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     textToSpeechWidget->setObjectName(QStringLiteral("texttospeechwidget"));
     vboxSieveEditorLayout->addWidget(textToSpeechWidget);
-
-    auto *textEdit = new KSieveUi::SieveScriptDebuggerTextEdit(this);
+#endif
+    auto textEdit = new KSieveUi::SieveScriptDebuggerTextEdit(this);
     connect(textEdit, &KSieveUi::SieveScriptDebuggerTextEdit::textChanged, this, &SieveScriptDebuggerFrontEndWidget::slotScriptTextChanged);
     mSieveTextEditWidget = new KSieveUi::SieveTextEditWidget(textEdit, this);
     mSieveTextEditWidget->setObjectName(QStringLiteral("sievetexteditwidget"));
     vboxSieveEditorLayout->addWidget(mSieveTextEditWidget);
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     connect(mSieveTextEditWidget->textEdit(), &SieveTextEdit::say, textToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
-
+#endif
     mSplitter->addWidget(sieveEditorWidget);
     mSplitter->setChildrenCollapsible(false);
 
@@ -101,7 +105,10 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
 
 SieveScriptDebuggerFrontEndWidget::~SieveScriptDebuggerFrontEndWidget()
 {
-    disconnect(mSieveTextEditWidget->textEdit(), &KSieveUi::SieveScriptDebuggerTextEdit::textChanged, this, &SieveScriptDebuggerFrontEndWidget::slotScriptTextChanged);
+    disconnect(mSieveTextEditWidget->textEdit(),
+               &KSieveUi::SieveScriptDebuggerTextEdit::textChanged,
+               this,
+               &SieveScriptDebuggerFrontEndWidget::slotScriptTextChanged);
 }
 
 void SieveScriptDebuggerFrontEndWidget::updateDebugButton()
@@ -127,7 +134,7 @@ QList<int> SieveScriptDebuggerFrontEndWidget::splitterSizes() const
 
 void SieveScriptDebuggerFrontEndWidget::slotEmailChanged(const QString &text)
 {
-    Q_UNUSED(text);
+    Q_UNUSED(text)
     updateDebugButton();
 }
 
@@ -142,7 +149,7 @@ void SieveScriptDebuggerFrontEndWidget::slotDebugScript()
         return;
     }
 
-    auto *temporaryFile = new QTemporaryFile();
+    auto temporaryFile = new QTemporaryFile();
     if (!temporaryFile->open()) {
         mSieveScriptDebuggerWarning->setErrorMessage(i18n("Failed to open temporary file."));
         delete temporaryFile;
@@ -169,7 +176,7 @@ void SieveScriptDebuggerFrontEndWidget::slotDebugScript()
     mProcess->start(QStringLiteral("sieve-test"), QStringList() << arguments);
     connect(mProcess, &QProcess::readyReadStandardOutput, this, &SieveScriptDebuggerFrontEndWidget::slotReadStandardOutput);
     connect(mProcess, &QProcess::readyReadStandardError, this, &SieveScriptDebuggerFrontEndWidget::slotReadErrorOutput);
-    connect(mProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &SieveScriptDebuggerFrontEndWidget::slotDebugFinished);
+    connect(mProcess, &QProcess::finished, this, &SieveScriptDebuggerFrontEndWidget::slotDebugFinished);
     mSieveTestResult->editor()->appendPlainText(QStringLiteral("--------------------------------------"));
     mSieveTestResult->editor()->appendPlainText(QLocale().toString(QDateTime::currentDateTime()));
     mSieveTestResult->editor()->appendPlainText(QStringLiteral("\n"));
