@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -23,9 +23,7 @@ VacationEditWidgetTest::VacationEditWidgetTest(QObject *parent)
 {
 }
 
-VacationEditWidgetTest::~VacationEditWidgetTest()
-{
-}
+VacationEditWidgetTest::~VacationEditWidgetTest() = default;
 
 void VacationEditWidgetTest::shouldHaveDefaultValue()
 {
