@@ -5,11 +5,8 @@
  */
 
 #include "vacationutilstest.h"
-#include "ksieveui/vacation/legacy/vacationutils.h"
 #include "ksieveui/vacation/vacationutils.h"
 
-#include <KMime/HeaderParsing>
-
 #include <QFile>
 #include <QTest>
 
@@ -63,7 +60,6 @@ void VacationUtilsTest::testParseActivate_data()
     QTest::newRow("deactivate") << QStringLiteral("vacation-deactivate.siv") << true << false;
     QTest::newRow("deactivate-multiple if") << QStringLiteral("vacation-deactivate-multiple.siv") << true << false;
     QTest::newRow("deactivate-complex") << QStringLiteral("vacation-deactivate-complex.siv") << true << false;
-    QTest::newRow("old") << QStringLiteral("vacation-old.siv") << true << true;
 }
 
 void VacationUtilsTest::testParseActivate()
@@ -88,7 +84,6 @@ void VacationUtilsTest::testParseScript_data()
 
     QTest::newRow("simple") << QStringLiteral("vacation-simple.siv") << QStringLiteral("vacation-deactivate.siv");
     QTest::newRow("complex") << QStringLiteral("vacation-complex.siv") << QStringLiteral("vacation-deactivate-complex.siv");
-    QTest::newRow("old") << QStringLiteral("vacation-old.siv") << QStringLiteral("vacation-deactivate-complex-old.siv");
 }
 
 void VacationUtilsTest::testParseScript()
