@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,15 +21,17 @@
 #include <QStackedWidget>
 #include <QTabBar>
 #include <QVBoxLayout>
+#include <kwidgetsaddons_version.h>
 
 using namespace KSieveUi;
-
+namespace
+{
+static const char myMultiImapVacationDialogGroupName[] = "MultiImapVacationDialog";
+}
 class KSieveUi::MultiImapVacationDialogPrivate
 {
 public:
-    MultiImapVacationDialogPrivate()
-    {
-    }
+    MultiImapVacationDialogPrivate() = default;
 
     QVector<VacationCreateScriptJob *> mListCreateJob;
     QTabWidget *mTabWidget = nullptr;
@@ -71,12 +73,20 @@ void MultiImapVacationDialog::reject()
         auto vacationPage = qobject_cast<VacationPageWidget *>(d->mTabWidget->widget(i));
         if (vacationPage) {
             if (vacationPage->wasChanged()) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                const int answer = KMessageBox::questionTwoActions(this,
+#else
                 const int answer = KMessageBox::questionYesNo(this,
-                                                              i18nc("@info", "Do you really want to cancel?"),
-                                                              i18nc("@title:window", "Confirmation"),
-                                                              KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
-                                                              KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")));
+#endif
+                                                                   i18nc("@info", "Do you really want to cancel?"),
+                                                                   i18nc("@title:window", "Confirmation"),
+                                                                   KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
+                                                                   KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+#else
                 if (answer == KMessageBox::Yes) {
+#endif
                     QDialog::reject(); // Discard current changes
                 }
                 canCloseDialog = false;
@@ -184,7 +194,7 @@ void MultiImapVacationDialog::createPage(const QString &serverName, const KSieve
 
 void MultiImapVacationDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "MultiImapVacationDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myMultiImapVacationDialogGroupName);
     const QSize size = group.readEntry("Size", QSize());
     if (size.isValid()) {
         resize(size);
@@ -195,7 +205,7 @@ void MultiImapVacationDialog::readConfig()
 
 void MultiImapVacationDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "MultiImapVacationDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), myMultiImapVacationDialogGroupName);
     group.writeEntry("Size", size());
 }
 
