@@ -1,15 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "vacationutils.h"
-#include "vacationscriptextractor.h"
-#include "legacy/vacationutils.h"
 #include "sieve-vacation.h"
-#include <KIdentityManagement/IdentityManager>
+#include "vacationscriptextractor.h"
 #include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
 
 #include <KLocalizedString>
 #include <QDate>
@@ -19,7 +18,7 @@
 using KMime::Types::AddrSpecList;
 using namespace KSieveUi;
 
-static inline QString dotstuff(QString s)     // krazy:exclude=passbyvalue
+static inline QString dotstuff(QString s) // krazy:exclude=passbyvalue
 {
     if (s.startsWith(QLatin1Char('.'))) {
         return QLatin1Char('.') + s.replace(QLatin1String("\n."), QStringLiteral("\n.."));
@@ -30,7 +29,8 @@ static inline QString dotstuff(QString s)     // krazy:exclude=passbyvalue
 
 static inline QString stringReplace(QString s)
 {
-    s.replace(QRegularExpression(QStringLiteral("[\n\t]+")), QStringLiteral(" "));
+    static QRegularExpression reg(QStringLiteral("[\n\t]+"));
+    s.replace(reg, QStringLiteral(" "));
     return s.replace(QLatin1Char('\"'), QStringLiteral("\\\""));
 }
 
@@ -62,17 +62,18 @@ KSieveUi::VacationUtils::MailAction KSieveUi::VacationUtils::defaultMailAction()
 
 QString KSieveUi::VacationUtils::defaultMessageText()
 {
-    return i18n("I am out of office till %1.\n"
-                "\n"
-                "In urgent cases, please contact Mrs. \"vacation replacement\"\n"
-                "\n"
-                "email: \"email address of vacation replacement\"\n"
-                "phone: +49 711 1111 11\n"
-                "fax.:  +49 711 1111 12\n"
-                "\n"
-                "Yours sincerely,\n"
-                "-- \"enter your name and email address here\"\n",
-                QLocale().toString(QDate::currentDate().addDays(1)));
+    return i18n(
+        "I am out of office till %1.\n"
+        "\n"
+        "In urgent cases, please contact Mrs. \"vacation replacement\"\n"
+        "\n"
+        "email: \"email address of vacation replacement\"\n"
+        "phone: +49 711 1111 11\n"
+        "fax.:  +49 711 1111 12\n"
+        "\n"
+        "Yours sincerely,\n"
+        "-- \"enter your name and email address here\"\n",
+        QLocale().toString(QDate::currentDate().addDays(1)));
 }
 
 int VacationUtils::defaultNotificationInterval()
@@ -122,18 +123,6 @@ QDate VacationUtils::defaultEndDate()
     return defaultStartDate().addDays(7);
 }
 
-VacationUtils::Vacation parseScriptLegacy(const QString &script)
-{
-    KSieveUi::VacationUtils::Vacation vacation;
-    vacation.active = true;
-    vacation.valid = Legacy::VacationUtils::parseScript(script, vacation.messageText,
-                                                        vacation.subject,
-                                                        vacation.notificationInterval, vacation.aliases,
-                                                        vacation.sendForSpam, vacation.reactOndomainName,
-                                                        vacation.startDate, vacation.endDate);
-    return vacation;
-}
-
 VacationUtils::Vacation VacationUtils::parseScript(const QString &script)
 {
     KSieveUi::VacationUtils::Vacation vacation;
@@ -155,8 +144,7 @@ VacationUtils::Vacation VacationUtils::parseScript(const QString &script)
     // the end, leading to a parse error.
     const QByteArray scriptUTF8 = script.trimmed().toUtf8();
     qCDebug(LIBKSIEVE_LOG) << "scriptUtf8 = \"" + scriptUTF8 + "\"";
-    KSieve::Parser parser(scriptUTF8.begin(),
-                          scriptUTF8.begin() + scriptUTF8.length());
+    KSieve::Parser parser(scriptUTF8.begin(), scriptUTF8.begin() + scriptUTF8.length());
     VacationDataExtractor vdx;
     SpamDataExtractor sdx;
     DomainRestrictionDataExtractor drdx;
@@ -164,10 +152,6 @@ VacationUtils::Vacation VacationUtils::parseScript(const QString &script)
     KSieveExt::MultiScriptBuilder tsb(&vdx, &sdx, &drdx, &dx);
     parser.setScriptBuilder(&tsb);
     if (!parser.parse() || !vdx.commandFound()) {
-        const auto vac = parseScriptLegacy(script);
-        if (vac.isValid()) {
-            return vac;
-        }
         vacation.active = false;
         vacation.valid = false;
         return vacation;
@@ -192,8 +176,7 @@ VacationUtils::Vacation VacationUtils::parseScript(const QString &script)
     if (!vacation.active && !vdx.ifComment().isEmpty()) {
         const QByteArray newScript = QByteArrayLiteral("if ") + vdx.ifComment().toUtf8() + QByteArrayLiteral("{vacation;}");
         tsb = KSieveExt::MultiScriptBuilder(&sdx, &drdx, &dx);
-        KSieve::Parser activeScriptParser(newScript.begin(),
-                                          newScript.begin() + newScript.length());
+        KSieve::Parser activeScriptParser(newScript.begin(), newScript.begin() + newScript.length());
         activeScriptParser.setScriptBuilder(&tsb);
         if (!activeScriptParser.parse()) {
             vacation.valid = false;
@@ -208,18 +191,6 @@ VacationUtils::Vacation VacationUtils::parseScript(const QString &script)
     vacation.endDate = dx.endDate();
     vacation.endTime = dx.endTime();
 
-    if (vacation.sendForSpam && vacation.reactOndomainName.isEmpty() && !vacation.startDate.isValid() && !vacation.endDate.isValid()) {
-        const auto vac = parseScriptLegacy(script);
-        if (vac.isValid()) {
-            vacation.sendForSpam = vac.sendForSpam;
-            vacation.reactOndomainName = vac.reactOndomainName;
-            vacation.startDate = vac.startDate;
-            vacation.startTime = vac.startTime;
-            vacation.endDate = vac.endDate;
-            vacation.endTime = vac.endTime;
-        }
-    }
-
     return vacation;
 }
 
@@ -238,22 +209,18 @@ QString KSieveUi::VacationUtils::composeScript(const Vacation &vacation)
     if (vacation.startDate.isValid()) {
         if (vacation.startTime.isValid()) {
             const QDateTime start(vacation.startDate, vacation.startTime);
-            condition.append(QStringLiteral("currentdate :value \"ge\" \"iso8601\" \"%1\"")
-                             .arg(start.toString(Qt::ISODate)));
+            condition.append(QStringLiteral("currentdate :value \"ge\" \"iso8601\" \"%1\"").arg(start.toString(Qt::ISODate)));
         } else {
-            condition.append(QStringLiteral("currentdate :value \"ge\" \"date\" \"%1\"")
-                             .arg(vacation.startDate.toString(Qt::ISODate)));
+            condition.append(QStringLiteral("currentdate :value \"ge\" \"date\" \"%1\"").arg(vacation.startDate.toString(Qt::ISODate)));
         }
     }
 
     if (vacation.endDate.isValid()) {
         if (vacation.endTime.isValid()) {
             const QDateTime end(vacation.endDate, vacation.endTime);
-            condition.append(QStringLiteral("currentdate :value \"le\" \"iso8601\" \"%1\"")
-                             .arg(end.toString(Qt::ISODate)));
+            condition.append(QStringLiteral("currentdate :value \"le\" \"iso8601\" \"%1\"").arg(end.toString(Qt::ISODate)));
         } else {
-            condition.append(QStringLiteral("currentdate :value \"le\" \"date\" \"%1\"")
-                             .arg(vacation.endDate.toString(Qt::ISODate)));
+            condition.append(QStringLiteral("currentdate :value \"le\" \"date\" \"%1\"").arg(vacation.endDate.toString(Qt::ISODate)));
         }
     }
 
@@ -273,7 +240,9 @@ QString KSieveUi::VacationUtils::composeScript(const Vacation &vacation)
         sl.reserve(vacation.aliases.count());
         AddrSpecList::const_iterator end = vacation.aliases.constEnd();
         for (AddrSpecList::const_iterator it = vacation.aliases.begin(); it != end; ++it) {
-            sl.push_back(QLatin1Char('"') + (*it).asString().replace(QLatin1Char('\\'), QStringLiteral("\\\\")).replace(QLatin1Char('"'), QStringLiteral("\\\"")) + QLatin1Char('"'));
+            sl.push_back(QLatin1Char('"')
+                         + (*it).asString().replace(QLatin1Char('\\'), QStringLiteral("\\\\")).replace(QLatin1Char('"'), QStringLiteral("\\\""))
+                         + QLatin1Char('"'));
             aliases.push_back((*it).asString());
         }
         addressesArgument += sl.join(QLatin1String(", ")) + QStringLiteral(" ] ");
@@ -345,11 +314,10 @@ QString KSieveUi::VacationUtils::mergeRequireLine(const QString &script, const Q
         return script;
     }
 
-    KSieve::Parser parser(scriptUTF8.begin(),
-                          scriptUTF8.begin() + scriptUTF8.length());
-    KSieve::Parser parserUpdate(scriptUpdateUTF8.begin(),
-                                scriptUpdateUTF8.begin() + scriptUpdateUTF8.length());
-    RequireExtractor rx, rxUpdate;
+    KSieve::Parser parser(scriptUTF8.begin(), scriptUTF8.begin() + scriptUTF8.length());
+    KSieve::Parser parserUpdate(scriptUpdateUTF8.begin(), scriptUpdateUTF8.begin() + scriptUpdateUTF8.length());
+    RequireExtractor rx;
+    RequireExtractor rxUpdate;
     parser.setScriptBuilder(&rx);
     parserUpdate.setScriptBuilder(&rxUpdate);
 
@@ -363,21 +331,13 @@ QString KSieveUi::VacationUtils::mergeRequireLine(const QString &script, const Q
         for (int i = insert; i <= endOld; ++i) {
             lines.removeAt(insert);
         }
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-        requirements = rx.requirements().toSet();
-#else
         const auto requirementsSet = rx.requirements();
         requirements = QSet<QString>(requirementsSet.begin(), requirementsSet.end());
-#endif
     }
 
     if (parserUpdate.parse() && rxUpdate.commandFound()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-        requirements += rxUpdate.requirements().toSet();
-#else
         const auto requirementsSet = rxUpdate.requirements();
         requirements += QSet<QString>(requirementsSet.begin(), requirementsSet.end());
-#endif
     }
 
     const int requirementscount = requirements.count();
@@ -404,11 +364,10 @@ QString KSieveUi::VacationUtils::updateVacationBlock(const QString &oldScript, c
         return oldScript;
     }
 
-    KSieve::Parser parserOld(oldScriptUTF8.begin(),
-                             oldScriptUTF8.begin() + oldScriptUTF8.length());
-    KSieve::Parser parserNew(newScriptUTF8.begin(),
-                             newScriptUTF8.begin() + newScriptUTF8.length());
-    VacationDataExtractor vdxOld, vdxNew;
+    KSieve::Parser parserOld(oldScriptUTF8.begin(), oldScriptUTF8.begin() + oldScriptUTF8.length());
+    KSieve::Parser parserNew(newScriptUTF8.begin(), newScriptUTF8.begin() + newScriptUTF8.length());
+    VacationDataExtractor vdxOld;
+    VacationDataExtractor vdxNew;
     RequireExtractor rx;
     KSieveExt::MultiScriptBuilder tsb(&vdxOld, &rx);
     parserOld.setScriptBuilder(&tsb);
@@ -425,7 +384,7 @@ QString KSieveUi::VacationUtils::updateVacationBlock(const QString &oldScript, c
             lines.removeAt(startOld);
         }
     } else {
-        if (rx.commandFound()) {                // after require
+        if (rx.commandFound()) { // after require
             startOld = rx.lineEnd() + 1;
         } else {
             startOld = 0;
