@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,6 +13,4 @@ AbstractRegexpEditorLineEdit::AbstractRegexpEditorLineEdit(QWidget *parent)
 {
 }
 
-AbstractRegexpEditorLineEdit::~AbstractRegexpEditorLineEdit()
-{
-}
+AbstractRegexpEditorLineEdit::~AbstractRegexpEditorLineEdit() = default;
